import os
import json
import pandas as pd

def read_json(file_name):
    with open(file_name, 'r') as file:
        data = json.load(file)
    return data

def read_excel(file_name):
    # read excel file
    data = pd.read_excel(file_name)
    # convert the data to a dictionary, where key is the 'ID' field
    excel_data = data.to_dict()
    data = {}
    for excel_idx, prompt_idx in excel_data['ID'].items():
        data[str(prompt_idx)] = {'id': prompt_idx, 'models': {}}
        for k in excel_data.keys():
            if k != 'ID':
                data[str(prompt_idx)]['models'][k] = [excel_data[k][excel_idx]]
        
    return data


def turn_list_into_dict(data, field="id"):
    new_data = {}
    for d in data:
        new_data[d[field]] = d
    return new_data
    
def aggregate_data(data, new_data):
    # check if the keys are the same
    # if data.keys() != new_data.keys():
    #     raise ValueError('Keys are not the same')
    # aggregrate the human ratings for each model under data[key]['models']
    
    ids = [item['id'] for item in new_data]
    ids += [item['id'] for item in data]
    for item in data:
        if item['id'] in ids:
            new_item = new_data[ids.index(item['id'])]
            for model_name in item['models']:
                item['models'][model_name] += new_item['models'][model_name]
    return data

files = [
        #  'annotation_0.json', 
        #  'annotation_0_new.json',
        # 't2v_prompts_for_annotation_subset_emily.json',
        # 't2v_prompts_for_annotation_subset_zhiqiu.json',
        't2v_prompts2_for_annotation.json',
        'genai_image_0_final.json',
        #  't2v_prompts_for_annotation_subset_1.json',
        #  't2v_prompts_for_annotation_subset_2.json',
        #  'annotation2.json',
         ]
# result_file = '30_subset_with_everyone.json'
# result_file = '30_subset_only_2.json'
# result_file = '30_subset_only_emily.json'
# result_file = '30_subset_only_zhiqiu.json'

result_file = 'genai_image_0_all.json'
data = None
for file_name in files:
    # check file type
    if file_name.endswith('.json'):
        annotator_result = read_json(file_name)
    else:
        print('unknown file type')
        # raise an error
        raise ValueError('Unknown file type')
    
    # annotator_result = turn_list_into_dict(annotator_result)
    if data is None:
        data = annotator_result
    else:
        data = aggregate_data(data, annotator_result)

# save the data
with open(result_file, 'w') as file:
    json.dump(data, file, indent=4)