def transform_markdown_v2(input_file_path, output_file_path):
    # Open the original markdown file for reading
    with open(input_file_path, 'r') as input_file:
        lines = input_file.readlines()

    # Prepare the transformed lines
    transformed_lines = []

    # Process the header and model names
    header_line = lines[0].strip().split("|")
    model_names = header_line[3:]  # Exclude ID, Prompt, and empty edges
    model_names = [item.strip() for item in model_names if not item == '']
    
    # Transform the header row for the new structure
    transformed_lines.append("| ID | Prompt | " + " | ".join([' -- ' for _ in range(len(model_names)-3)]) + " |\n")
    transformed_lines.append("|---|---|---|---|---|\n")

    # Process each data row
    for line in lines[2:]:  # Skip the header and the separator
        parts = line.strip().split("|")
        if len(parts) < 8:  # Ensure the line is a valid row
            continue
        id_, prompt, *images = parts[1:-1]  # Exclude empty edges
        # Split images into groups of three and process each group
        for i in range(0, len(images), 3):
            image_group = images[i:i+3]
            # For each group, create a new row with ID, prompt (only for the first group), and images
            if i == 0:  # Include ID and prompt for the first group only
                new_row = f"| {id_} | {prompt} | " + " | ".join(image_group) + " |\n"
            else:  # Leave ID and prompt columns empty for subsequent groups
                new_row = "| | | " + " | ".join(image_group) + " |\n"
            transformed_lines.append(new_row)
            # Immediately follow with a row for model names corresponding to this group
            model_row = "| | | " + " | ".join(model_names[i:i+3]) + " |\n"
            transformed_lines.append(model_row)
    # Write the transformed lines to a new file
    with open(output_file_path, 'w') as output_file:
        output_file.writelines(transformed_lines)

# Specify the input and output file paths
input_file_path = 'image_visualization_270_399_1x6.md'
output_file_path = 'image_visualization_270_399_2x3.md'

# Transform the markdown
transform_markdown_v2(input_file_path, output_file_path)
