import os
import json
import pandas as pd

def read_json(file_name):
    with open(file_name, 'r') as file:
        data = json.load(file)
    return data

def read_excel(file_name):
    # read excel file
    data = pd.read_excel(file_name)
    # convert the data to a dictionary, where key is the 'ID' field
    excel_data = data.to_dict()
    data = {}
    for excel_idx, prompt_idx in excel_data['ID'].items():
        data[str(prompt_idx)] = {'id': prompt_idx, 'models': {}}
        for k in excel_data.keys():
            if k != 'ID':
                data[str(prompt_idx)]['models'][k] = [excel_data[k][excel_idx]]
        
    return data


def turn_list_into_dict(data, field="id"):
    new_data = {}
    for d in data:
        new_data[d[field]] = d
    return new_data
    
def aggregate_data(data, new_data):
    # check if the keys are the same
    # if data.keys() != new_data.keys():
    #     raise ValueError('Keys are not the same')
    # aggregrate the human ratings for each model under data[key]['models']
    for k in data.keys():
        for model_name in data[k]['models']:
            data[k]['models'][model_name] += new_data[k]['models'][model_name]
    return data

files = [
        #  'video_emily.json', 
        #  'video_zhiqiu.json', 
        #  'video_annotator_1.json', 
         'video_annotator_2.json', 
         ]
# result_file = '30_subset_with_everyone.json'
# result_file = '30_subset_video_with_everyone.json'
# result_file = '30_subset_only_emily.json'
# result_file = '30_subset_only_zhiqiu.json'
# result_file = '30_subset_only_1_and_2.json'
# result_file = '30_subset_only_1.json'
result_file = '30_subset_only_2.json'

data = None
for file_name in files:
    # check file type
    if file_name.endswith('.json'):
        annotator_result = read_json(file_name)
    elif file_name.endswith('.xlsx'):
        annotator_result = read_excel(file_name)
    else:
        print('unknown file type')
        # raise an error
        raise ValueError('Unknown file type')
    
    annotator_result = turn_list_into_dict(annotator_result)
    if data is None:
        data = annotator_result
    else:
        data = aggregate_data(data, annotator_result)

# check the krippendorff
all_ratings = [[] for _ in range(len(data['00006']['models']['Floor33']))]
for k in data.keys():
    for model_name in data[k]['models']:
        for rater_idx, rating in enumerate(data[k]['models'][model_name]):
            all_ratings[rater_idx].append(rating)

# Now compute the Krippendorff's alpha
import krippendorff
# alpha = krippendorff.alpha(all_ratings, level_of_measurement='ordinal')
# print(f"Krippendorff's alpha: {alpha}")
# save the data
with open(result_file, 'w') as file:
    json.dump(data, file, indent=4)