import os
import json

def read_txt_file(file_path):
    """读取.txt文件并返回行列表。"""
    with open(file_path, 'r', encoding='utf-8') as file:
        return [line.strip() for line in file.readlines()]

def read_json_file(file_path):
    with open(file_path, 'r', encoding='utf-8') as f:
        data = json.load(f)
    prompts = []
    for item in data:
        prompts.append({"id": int(item["id"]), "prompt": item["prompt"]})
    return prompts

# def generate_markdown_files(models, prompts, base_dir, num_files=20):
#     """为给定的模型和提示生成Markdown文件，以可视化视频。"""
#     prompts_per_file = len(prompts) // num_files
    
#     for file_index in range(num_files):
#         # 定义当前文件中提示的起始和结束索引
#         start_index = file_index * prompts_per_file
#         end_index = start_index + prompts_per_file
#         if file_index == num_files - 1:  # 在最后一个文件中包含所有剩余的提示
#             end_index = len(prompts)
        
#         # 开始构建Markdown内容
#         markdown_content = "# Video Visualizations\n\n"
#         markdown_content += "| ID | Prompt | " + " | ".join(models) + " |\n"
#         markdown_content += "|----|--------|" + "|".join(["---" for _ in models]) + "|\n"
        
#         for prompt_index in range(start_index, end_index):
#             prompt = prompts[prompt_index]
#             row = f"| {prompt_index + 1} | {prompt} |"
#             for model in models:
#                 video_filename = f"{prompt_index+1:05d}.mp4"
#                 video_path = os.path.join(base_dir, model, video_filename)  # 生成绝对路径
#                 # video_path = video_path.replace('\\', '/')  # 将路径中的反斜杠替换为正斜杠
#                 video_html = f'<video width="320" height="240" controls><source src="file:///{video_path}" type="video/mp4"></video>'
#                 row += f" {video_html} |"
#             markdown_content += row + "\n"
        
#         # 将Markdown内容写入文件
#         markdown_file_path = os.path.join(base_dir, f"video_visualization_{start_index}_{end_index}.md")
#         with open(markdown_file_path, 'w', encoding='utf-8') as markdown_file:
#             markdown_file.write(markdown_content)
#         print(f"Markdown文件生成：{markdown_file_path}")

# def generate_markdown_files(models, prompts, num_files=1):
#     """Generate Markdown files to visualize videos for given models and prompts."""
#     prompts_per_file = len(prompts) // num_files
    
#     for file_index in range(num_files):
#         # Define the start and end index for prompts in the current file
#         start_index = file_index * prompts_per_file
#         end_index = start_index + prompts_per_file
#         if file_index == num_files - 1:  # Include any remaining prompts in the last file
#             end_index = len(prompts)
        
#         # Start Markdown content
#         markdown_content = "# Video Visualizations\n\n"
#         markdown_content += "| ID | Prompt | " + " | ".join(models) + " |\n"
#         markdown_content += "|----|--------|" + "|".join(["---" for _ in models]) + "|\n"
        
#         for prompt_index in range(start_index, end_index):
#             prompt = prompts[prompt_index]
#             row = f"| {prompt_index + 1} | {prompt} |"
#             for model in models:
#                 video_filename = f"{prompt_index+1:05d}.mp4"
#                 video_path = os.path.join(model, video_filename)
#                 video_html = f'<video width="320" height="240" controls><source src="{video_path}" type="video/mp4"></video>'
#                 row += f" {video_html} |"
#             markdown_content += row + "\n"
        
#         # Write to Markdown file
#         markdown_file_path = f"video_visualization_{start_index}_{end_index}.md"
#         with open(markdown_file_path, 'w') as markdown_file:
#             markdown_file.write(markdown_content)
#         print(f"Markdown file generated: {markdown_file_path}")


def generate_markdown_files(models, prompts, num_files=10):
    """Generate Markdown files to visualize videos for given models and prompts."""
    prompts_per_file = len(prompts) // num_files
    
    for file_index in range(num_files):
        # Define the start and end index for prompts in the current file
        start_index = file_index * prompts_per_file
        end_index = start_index + prompts_per_file
        if file_index == num_files - 1:  # Include any remaining prompts in the last file
            end_index = len(prompts)
        
        # Start Markdown content
        markdown_content = "# Video Visualizations\n\n"
        markdown_content += "| ID | Prompt | " + " | ".join(models) + " |\n"
        markdown_content += "|----|--------|" + "|".join(["---" for _ in models]) + "|\n"
        
        for prompt_index in range(start_index, end_index):
            prompt = prompts[prompt_index]['prompt']
            row = f"| {prompts[prompt_index]['id']} | {prompt} |"
            for model in models:
                video_filename = f"{prompts[prompt_index]['id']:05d}.mp4"
                video_path = os.path.join(model, video_filename)
                video_html = f'<video width="320" height="240" controls><source src="{video_path}" type="video/mp4"></video>'
                row += f" {video_html} |"
            markdown_content += row + "\n"
        
        # Write to Markdown file
        markdown_file_path = f"video_visualization_{start_index}_{end_index}.md"
        with open(markdown_file_path, 'w') as markdown_file:
            markdown_file.write(markdown_content)
        print(f"Markdown file generated: {markdown_file_path}")


# 模型和提示的设置
models = ['Floor33', 'Gen2', 'Pika_v1', 'Modelscope', 'Zeroscope']
prompts = read_json_file("t2v_prompts_for_annotation.json")
base_dir = os.getcwd()  # 获取当前工作目录作为基础目录

# 生成Markdown文件
# generate_markdown_files(models, prompts, base_dir)
generate_markdown_files(models, prompts)